"use client";
import { Swiper, SwiperSlide } from "swiper/react";
import "swiper/css";
import "swiper/css/navigation";
import "swiper/css/pagination";
import "swiper/css/scrollbar";
import "swiper/css/autoplay";
import "swiper/css/effect-fade";
import FallbackImages from "@/utility/FallBackImage/FallBackImages";
import Link from "next/link";
import { useEffect, useState } from "react";
import './ReletedNews.css';
import { FaPlus } from "react-icons/fa";
const ReletedSingle = ({ singleNewsDetails }) => {
  const [relatedNews, setRelatedNews] = useState([]);

  useEffect(() => {
    const fetchRelatedNews = async () => {
      if (!singleNewsDetails?.category_id) {
        return;
      }

      const route = `https://backoffice.ajkal.us/category-news/${singleNewsDetails.category_id}`;

      try {
        const response = await fetch(route, { cache: "no-cache" });
        if (!response.ok) {
          throw new Error(
            `Failed to fetch related news: ${response.statusText}`
          );
        }
        const data = await response.json();
        setRelatedNews(data?.data || []);
      } catch (error) {
        console.error("Error fetching related news:", error);
      }
    };

    fetchRelatedNews();
  }, [singleNewsDetails?.category_id]);
  console.log(relatedNews, "relatedNews")
  return (
    <>
      <Swiper
        spaceBetween={10}
        loop={true}
        dots={false}
        pagination={{ clickable: true }}
        autoplay={{
          delay: 3000,
          disableOnInteraction: false,
        }}
        breakpoints={{
          640: { slidesPerView: 1 },
          768: { slidesPerView: 2 },
          1024: { slidesPerView: 3 },
        }}
      >
        {relatedNews.length > 0 ? (
          relatedNews.map((slide) => (
            <SwiperSlide key={slide.id} className="my-4">
              <div
                className="card shadow-sm border-0 mb-3"
                style={{ width: "100%", height: "350px" }}
              >
                <FallbackImages
                  src={`https://ajkal.us/img/news/${slide.title_img}`}
                  alt={slide.news_title}
                  className="rounded-3 releted_news"
                  width={200}
                  height={180}
                />
                <div className="card-body py-4">
                  <h5
                    className="card-title"
                    style={{ width: "100%", height: "50px" }}
                  >
                    {slide.news_title}
                  </h5>
                  <p className="card-text">{slide.description}</p>
                  <Link
                    href={`/news-detail/${slide?.id}`}
                    className="btn btn-outline-dark mt-4 bt-sm border-0"
                  >
                    <FaPlus size={14} color="black" /> Read More
                  </Link>
                </div>
              </div>
            </SwiperSlide>
          ))
        ) : (
          <div>No featured items for this category.</div>
        )}

        {/* Custom navigation buttons */}
        {/* <div className="swiper-button-next" aria-label="Next slide"></div>
        <div className="swiper-button-prev" aria-label="Previous slide"></div> */}
      </Swiper>
    </>
  );
};

export default ReletedSingle;
